@@ -49,3 +49,27 @@ sub get_schema_from_pod {
 }
 
 1;
+
+=head1 NAME
+
+CPAN::Packager::Util - Utility class 
+
+=head1 SYNOPSIS
+
+  use CPAN::Packager::Util;
+
+=head1 DESCRIPTION
+
+
+=head1 AUTHOR
+
+Takatoshi Kitano E<lt>kitano.tk@gmail.comE<gt>
+
+=head1 SEE ALSO
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
